/*****************************************************************************
   driverevents.c - Events from the driver processing
   Copyright (C) 2000 by Jaroslav Kysela <perex@suse.cz>
   
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
******************************************************************************/

#include "envy24control.h"

static void control_switch(void *private_data, int cmd, int iface, snd_switch_list_item_t *item)
{
	if (cmd != SND_CTL_READ_SWITCH_VALUE)
		return;
	if (iface != SND_CTL_IFACE_CONTROL)
		return;
	if (!strcmp(item->name, "Multi Track Route")) {
		patchbay_update();
		return;
	}
	if (!strcmp(item->name, "Multi Track S/PDIF Master")) {
		master_clock_update();
		return;
	}
	if (!strcmp(item->name, "Word Clock Sync")) {
		master_clock_update();
		return;
	}
	if (!strcmp(item->name, "Multi Track Volume Rate")) {
		volume_change_rate_update();
		return;
	}
	if (!strcmp(item->name, "S/PDIF Input Optical")) {
		spdif_input_update();
		return;
	}
	if (!strcmp(item->name, "Delta S/PDIF Output Defaults")) {
		spdif_output_update();
		return;
	}
}

static snd_ctl_callbacks_t control_callbacks = {
	NULL,			/* private data */
	NULL,			/* rebuild - FIXME!! */
	control_switch,
	{ NULL, }
};

void control_input_callback(gpointer data, gint source, GdkInputCondition condition)
{
	snd_ctl_read(card_ctl, &control_callbacks);
}

static void mixer_element(void *private_data, int cmd, snd_mixer_eid_t *eid)
{
	if (!strcmp(eid->name, "Multi Playback Volume")) {
		mixer_update_stream(eid->index + 1, 1, 0);
		return;
	}
	if (!strcmp(eid->name, "Multi Capture Volume")) {
		mixer_update_stream(eid->index + 11, 1, 0);
		return;
	}
	if (!strcmp(eid->name, "Multi Playback Switch")) {
		mixer_update_stream(eid->index + 1, 0, 1);
		return;
	}
	if (!strcmp(eid->name, "Multi Capture Switch")) {
		mixer_update_stream(eid->index + 11, 0, 1);
		return;
	}
}

static snd_mixer_callbacks_t mixer_callbacks = {
	NULL,			/* private data */
	NULL,			/* rebuild - FIXME!! */
	mixer_element,
	NULL,			/* group */
	{ NULL, }
};

void mixer_input_callback(gpointer data, gint source, GdkInputCondition condition)
{
	snd_mixer_read(card_mixer, &mixer_callbacks);
}
